- openai does not return the usage currently
- Standard the Tool Return format for the functions
- Fixed OpenAI provider input type error
- self._formatted_tools  fix this return type
- specifying tool return type
